import {
  select,
  csv,
  scaleLinear,
  axisLeft,
  axisBottom,
  extent,
  max,
} from 'd3';

export const main = async (container) => {
  // Load and parse data
  const data = await csv(
    'https://raw.githubusercontent.com/Anushapodapati99/SCIENTIFIC-DATA-VISUALIZATION-DATASETS/main/district_level_data.csv',
  );

  // Parse numerical values from the data
  data.forEach((d) => {
    d['RICE AREA (1000 ha)'] = +d['RICE AREA (1000 ha)']; // convert to hectares
    d['RICE PRODUCTION (1000 tons)'] =
      +d['RICE PRODUCTION (1000 tons)']; // convert to tons
  });

  // Define dimensions
  const dimensions = {
    width: 960,
    height: 500,
    margin: { top: 20, right: 30, bottom: 50, left: 50 },
  };

  // Define scales
  const xScale = scaleLinear()
    .domain(extent(data, (d) => d['RICE AREA (1000 ha)']))
    .range([
      0,
      dimensions.width -
        dimensions.margin.left -
        dimensions.margin.right,
    ]);

  const yScale = scaleLinear()
    .domain([
      0,
      max(data, (d) => d['RICE PRODUCTION (1000 tons)']),
    ])
    .range([
      dimensions.height -
        dimensions.margin.top -
        dimensions.margin.bottom,
      0,
    ]);

  // Append SVG to the container
  const svg = select(container)
    .append('svg')
    .attr('width', dimensions.width)
    .attr('height', dimensions.height)
    .append('g')
    .attr(
      'transform',
      `translate(${dimensions.margin.left},${dimensions.margin.top})`,
    );

  // Add X axis
  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${dimensions.height - dimensions.margin.top - dimensions.margin.bottom})`,
    )
    .call(axisBottom(xScale));

  // Add Y axis
  svg.append('g').call(axisLeft(yScale));

  // Add dots for scatter plot
  svg
    .append('g')
    .selectAll('dot')
    .data(data)
    .enter()
    .append('circle')
    .attr('cx', (d) => xScale(d['RICE AREA (1000 ha)']))
    .attr('cy', (d) =>
      yScale(d['RICE PRODUCTION (1000 tons)']),
    )
    .attr('r', 3)
    .style('fill', '#69b3a2');

  // Add labels
  svg
    .append('text')
    .attr('text-anchor', 'end')
    .attr(
      'x',
      dimensions.width / 2 + dimensions.margin.left,
    )
    .attr(
      'y',
      dimensions.height - dimensions.margin.top + 20,
    )
    .text('Area under Cultivation (ha)');

  svg
    .append('text')
    .attr('text-anchor', 'end')
    .attr('transform', 'rotate(-90)')
    .attr('y', -dimensions.margin.left + 20)
    .attr(
      'x',
      -dimensions.margin.top - dimensions.height / 2 + 100,
    )
    .text('Production (tons)');
};

main(document.body); // Replace `document.body` with the actual container element
